@@ -9,13 +9,10 @@ if [ ! -r perlfiles.tar.gz ]; then
     exit 1
 fi
 
-NSISDIR=`mktemp -d /tmp/gipXXXXXX`
-
-cp -av windows/get_iplayer windows/installer_files $NSISDIR
-tar xvfz perlfiles.tar.gz -C $NSISDIR/get_iplayer
-mkdir -p $NSISDIR/get_iplayer/Downloads
-cd $NSISDIR
-makensis -NOCD get_iplayer/get_iplayer_setup.nsi
-cd -
-mv -v $NSISDIR/get_iplayer_setup_*.exe .
-rm -rf $NSISDIR
+GIPDIR=`dirname $0`
+TMPDIR=`mktemp -d /tmp/gipXXXXXX`
+mkdir "$TMPDIR/perlfiles"
+tar xvfz perlfiles.tar.gz -C "$TMPDIR/perlfiles"
+makensis -NOCD -DBUILDPATH="$TMPDIR" -DSOURCEPATH="$GIPDIR" "$GIPDIR/windows/get_iplayer_setup.nsi"
+mv -v $TMPDIR/get_iplayer_setup*.exe .
+rm -rf $TMPDIR
